@@ -4,14 +4,17 @@ Convert different markups to HTML
 
 import html
 import re
+from textwrap import shorten
 
 import markdown as md
 
 
 URL = re.compile(r'((?:https?|mailto|ftp|gopher|gemini)://\S+)', re.IGNORECASE)
+SLASH = re.compile(r'([^/])/([^/])')
 
 
 def plaintext(text, escape=html.escape):
+    placeholder = "…"
     output = []
     for paragraph in text.split('\n\n'):
         if not paragraph.strip():
@@ -21,7 +24,9 @@ def plaintext(text, escape=html.escape):
             if not chunk.strip():
                 continue
             if URL.fullmatch(chunk):
-                chunks.append(f'<a href="{chunk}">{escape(chunk)}</a>')
+                short = shorten(SLASH.sub(r'\1 \2', chunk), width=80, placeholder=placeholder)
+                visible = chunk[:len(short)] + short[-len(placeholder):]
+                chunks.append(f'<a href="{chunk}">{visible}</a>')
             else:
                 chunks.append(escape(chunk))
         paragraph = '\n'.join(chunks)
